Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1105)

Unified Diff: content/public/browser/render_widget_host_view.h

Issue 2688883002: Revert [MacViews] Implemented text context menu (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/render_widget_host_view.h
diff --git a/content/public/browser/render_widget_host_view.h b/content/public/browser/render_widget_host_view.h
index 04c70b7c69af0d120fd2d57564c2d889e148052d..71c693bf7c3c09c90b6df776d1afe9dff015fbf2 100644
--- a/content/public/browser/render_widget_host_view.h
+++ b/content/public/browser/render_widget_host_view.h
@@ -185,10 +185,14 @@ class CONTENT_EXPORT RenderWidgetHostView {
// Brings up the dictionary showing a definition for the selected text.
virtual void ShowDefinitionForSelection() = 0;
- // Tells the view to speak the currently selected text. If there is no
- // selection, read everything.
+ // Returns |true| if Mac OS X text to speech is supported.
+ virtual bool SupportsSpeech() const = 0;
+ // Tells the view to speak the currently selected text.
virtual void SpeakSelection() = 0;
-
+ // Returns |true| if text is currently being spoken by Mac OS X.
+ virtual bool IsSpeaking() const = 0;
+ // Stops speaking, if it is currently in progress.
+ virtual void StopSpeaking() = 0;
#endif // defined(OS_MACOSX)
};
« no previous file with comments | « content/browser/renderer_host/render_widget_host_view_mac_unittest.mm ('k') | content/test/test_render_view_host.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698